@@ -31,7 +31,7 @@ from .align_pipe import rotate_pixtables
 from .mpdaf_pipe import MuseCubeMosaic, MuseCube
 from .prep_recipes_pipe import dict_products_scipost
 from .version import __version__ as version_pack
-from .util_pipe import add_string
+from .util_pipe import add_string, get_pointing_name
 
 from astropy.table import Table
 
@@ -330,7 +330,7 @@ class MusePipeSample(object):
             if self.init_pipes:
                 self.set_pipe_target(targetname, **kwargs_init)
 
-    def _check_list_datasets(self, targetname, list_datasets):
+    def _check_list_datasets_for_target(self, targetname, list_datasets):
         """Check if dataset is in the list of datasets
         Returns the list of datasets if ok. If not, return an empty list
 
@@ -408,7 +408,7 @@ class MusePipeSample(object):
         upipe.print_info("=== Initialising MusePipe for Target {name} ===".format(name=targetname))
 
         # Check if datasets are valid
-        list_datasets = self._check_list_datasets(targetname, list_datasets)
+        list_datasets = self._check_list_datasets_for_target(targetname, list_datasets)
         if len(list_datasets) == 0:
             return
 
@@ -602,7 +602,7 @@ class MusePipeSample(object):
             upipe.print_info("=========== CREATION OF WCS MASKS ==============")
             mosaic_wcs = kwargs.pop("mosaic_wcs", True)
             reference_cube = kwargs.pop("reference_cube", True)
-            datasets_wcs = kwargs.pop("datasets_wcs", True)
+            pointings_wcs = kwargs.pop("pointings_wcs", True)
             refcube_name = kwargs.pop("refcube_name", None)
             full_ref_wcs = kwargs.pop("full_ref_wcs", None)
             default_comb_folder = self.targets[targetname].combcubes_path
@@ -615,7 +615,7 @@ class MusePipeSample(object):
                                       reference_cube=reference_cube,
                                       refcube_name=refcube_name,
                                       mosaic_wcs=mosaic_wcs,
-                                      datasets_wcs=datasets_wcs,
+                                      pointings_wcs=pointings_wcs,
                                       list_datasets=list_datasets,
                                       ref_wcs=full_ref_wcs,
                                       folder_ref_wcs=folder_full_ref_wcs,
@@ -658,7 +658,7 @@ class MusePipeSample(object):
 
         """
         # Check if datasets are valid
-        list_datasets = self._check_list_datasets(targetname, list_datasets)
+        list_datasets = self._check_list_datasets_for_target(targetname, list_datasets)
         upipe.print_info(f"List of datasets to be reduced: {list_datasets}")
         if len(list_datasets) == 0:
             return
@@ -686,7 +686,7 @@ class MusePipeSample(object):
 
         # Running the scipost_perexpo for all datasets individually
         for dataset in list_datasets:
-            obname = self.pipes[targetname][dataset]._get_dataset_name(dataset)
+            obname = self.pipes[targetname][dataset]._get_dataset_name()
             if wcs_auto:
                 ref_wcs = f"{wcs_suffix}_{obname}.fits"
             if ref_wcs is not None:
@@ -736,7 +736,7 @@ class MusePipeSample(object):
                 first_recipe=recipe_name, last_recipe=recipe_name, **kwargs)
 
         # Check if datasets are valid
-        list_datasets = self._check_list_datasets(targetname, list_datasets)
+        list_datasets = self._check_list_datasets_for_target(targetname, list_datasets)
         if len(list_datasets) == 0:
             return
 
@@ -801,7 +801,7 @@ class MusePipeSample(object):
             self.set_pipe_target(targetname=targetname, list_datasets=list_datasets, **kwargs)
 
         # Check if datasets are valid
-        list_datasets = self._check_list_datasets(targetname, list_datasets)
+        list_datasets = self._check_list_datasets_for_target(targetname, list_datasets)
         if len(list_datasets) == 0:
             return
 
@@ -835,7 +835,7 @@ class MusePipeSample(object):
                                  list_datasets=list_datasets, **kwargs)
 
         # Check if datasets are valid
-        list_datasets = self._check_list_datasets(targetname, list_datasets)
+        list_datasets = self._check_list_datasets_for_target(targetname, list_datasets)
 
         if len(list_datasets) == 0:
             return
@@ -870,20 +870,18 @@ class MusePipeSample(object):
         -----
         targetname: str [None]
             Name of target
-        list_pointings: list [or None=default meaning all pointings]
-            List of pointings (e.g., [1,2,3])
+        list_datasets: list [or None=default meaning all datasets]
+            List of datasets (e.g., [1,2,3])
         """
         add_targetname = kwargs.pop("add_targetname", self.add_targetname)
-        # Check if pointings are valid
-        list_pointings = self._check_pointings_list(targetname, list_pointings)
-        # Using the obname of the first pointing to define the function
-        get_pointing_name = self.pipes[targetname][list_pointings[0]]._get_pointing_name
+        # # Check if datasets are valid
+        # list_pointings = self._check_list_datasets_for_target(targetname, list_pointings)
         if len(list_pointings) == 0:
             return
 
         # Make a list for the masking of the cubes to take into account
-        list_pointing_names = [f"{get_pointing_name(pointing)}"
-                              for pointing in list_pointings]
+        list_pointings_names = [f"{get_pointing_name(pointing)}"
+                                for pointing in list_pointings]
 
         default_comb_folder = self.targets[targetname].combcubes_path
         folder_ref_wcs = kwargs.pop("folder_ref_wcs", default_comb_folder)
@@ -900,7 +898,7 @@ class MusePipeSample(object):
                                                        folder_ref_wcs=folder_ref_wcs,
                                                        folder_cubes=folder_cubes,
                                                        prefix_cubes=prefix_cubes,
-                                                       list_suffix=list_pointing_names,
+                                                       list_suffix=list_pointings_names,
                                                        **kwargs)
 
     def convolve_mosaic_per_pointing(self, targetname=None, list_pointings=None,
