@@ -16,16 +16,19 @@ from scipy import ndimage as nd
 from astropy.stats import mad_std, sigma_clip, sigma_clipped_stats
 from astropy.convolution import Gaussian2DKernel, convolve
 
+# Import package modules
+from . import util_pipe as upipe
+
+
 try:
     from photutils.detection import IRAFStarFinder
     _photutils = True
 except ImportError:
+    upipe.print_warning("The python packages photutils is not available. "
+                        "If you wish to use star masking. Please install it.")
     _photutils = False
 
 
-# Import package modules
-from . import util_pipe as upipe
-
 
 def select_spaxels(maskdict, maskname, x, y):
     """Selecting spaxels defined by their coordinates
@@ -286,8 +289,8 @@ def chunk_stats(list_arrays, chunk_size=15):
 
     narrays = len(list_arrays)
 
-    nchunk_x = np.int(list_arrays[0].shape[0] // chunk_size - 1)
-    nchunk_y = np.int(list_arrays[0].shape[1] // chunk_size - 1)
+    nchunk_x = int(list_arrays[0].shape[0] // chunk_size - 1)
+    nchunk_y = int(list_arrays[0].shape[1] // chunk_size - 1)
     # Check that all arrays have the same size
     med_array = np.zeros((narrays, nchunk_x * nchunk_y), dtype=np.float64)
     std_array = np.zeros_like(med_array)
@@ -579,4 +582,4 @@ def mask_point_sources(ima, fwhm=3, mask_radius=30., brightest=5, sigma=3., verb
             mask = dist_from_source < mask_radius
             mima[mask] = np.nan
 
-    return mima
\ No newline at end of file
+    return mima
